==> servicecatalog-0.20.0-sources.jar: software/amazon/awscdk/services/servicecatalog/cloudformation/PortfolioResource.java <==
package software.amazon.awscdk.services.servicecatalog.cloudformation;

/**
 * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-servicecatalog-portfolio.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.7.12 (build 82990c5)", date = "2018-12-13T10:23:12.491Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.servicecatalog.$Module.class, fqn = "@aws-cdk/aws-servicecatalog.cloudformation.PortfolioResource")
public class PortfolioResource extends software.amazon.awscdk.Resource {
    protected PortfolioResource(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
        super(mode);
    }
    static {
        RESOURCE_TYPE_NAME = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.servicecatalog.cloudformation.PortfolioResource.class, "resourceTypeName", java.lang.String.class);
    }
    /**
     * Creates a new ``AWS::ServiceCatalog::Portfolio``.
     * @param parent the ``cdk.Construct`` this ``PortfolioResource`` is a part of
     * @param name the name of the resource in the ``cdk.Construct`` tree
     * @param properties the properties of this ``PortfolioResource``
     */
    public PortfolioResource(final software.amazon.awscdk.Construct parent, final java.lang.String name, final software.amazon.awscdk.services.servicecatalog.cloudformation.PortfolioResourceProps properties) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, java.util.stream.Stream.concat(java.util.stream.Stream.concat(java.util.stream.Stream.of(java.util.Objects.requireNonNull(parent, "parent is required")), java.util.stream.Stream.of(java.util.Objects.requireNonNull(name, "name is required"))), java.util.stream.Stream.of(java.util.Objects.requireNonNull(properties, "properties is required"))).toArray());
    }

    @Override
    protected java.util.Map<java.lang.String, java.lang.Object> renderProperties(final java.lang.Object properties) {
        return this.jsiiCall("renderProperties", java.util.Map.class, java.util.stream.Stream.of(java.util.Objects.requireNonNull(properties, "properties is required")).toArray());
    }
    /**
     * The CloudFormation resource type name for this resource class.
     */
    public final static java.lang.String RESOURCE_TYPE_NAME;

    public java.lang.String getPortfolioId() {
        return this.jsiiGet("portfolioId", java.lang.String.class);
    }

    /**
     * @cloudformation_attribute PortfolioName
     */
    public java.lang.String getPortfolioName() {
        return this.jsiiGet("portfolioName", java.lang.String.class);
    }

    public software.amazon.awscdk.services.servicecatalog.cloudformation.PortfolioResourceProps getPropertyOverrides() {
        return this.jsiiGet("propertyOverrides", software.amazon.awscdk.services.servicecatalog.cloudformation.PortfolioResourceProps.class);
    }
}

==> servicecatalog-0.21.0-sources.jar: software/amazon/awscdk/services/servicecatalog/cloudformation/PortfolioResource.java <==
package software.amazon.awscdk.services.servicecatalog.cloudformation;

/**
 * @deprecated "cloudformation.PortfolioResource" will be deprecated in a future release in favor of "CfnPortfolio" (see https://github.com/awslabs/aws-cdk/issues/878)
 * @link http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-servicecatalog-portfolio.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.7.12 (build 82990c5)", date = "2018-12-20T13:28:54.839Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.servicecatalog.$Module.class, fqn = "@aws-cdk/aws-servicecatalog.cloudformation.PortfolioResource")
public class PortfolioResource extends software.amazon.awscdk.Resource {
    protected PortfolioResource(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
        super(mode);
    }
    static {
        RESOURCE_TYPE_NAME = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.servicecatalog.cloudformation.PortfolioResource.class, "resourceTypeName", java.lang.String.class);
    }
    /**
     * Creates a new ``AWS::ServiceCatalog::Portfolio``.
     * @param parent the ``cdk.Construct`` this ``PortfolioResource`` is a part of
     * @param name the name of the resource in the ``cdk.Construct`` tree
     * @param properties the properties of this ``PortfolioResource``
     */
    public PortfolioResource(final software.amazon.awscdk.Construct parent, final java.lang.String name, final software.amazon.awscdk.services.servicecatalog.cloudformation.PortfolioResourceProps properties) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, java.util.stream.Stream.concat(java.util.stream.Stream.concat(java.util.stream.Stream.of(java.util.Objects.requireNonNull(parent, "parent is required")), java.util.stream.Stream.of(java.util.Objects.requireNonNull(name, "name is required"))), java.util.stream.Stream.of(java.util.Objects.requireNonNull(properties, "properties is required"))).toArray());
    }

    @Override
    protected java.util.Map<java.lang.String, java.lang.Object> renderProperties(final java.lang.Object properties) {
        return this.jsiiCall("renderProperties", java.util.Map.class, java.util.stream.Stream.of(java.util.Objects.requireNonNull(properties, "properties is required")).toArray());
    }
    /**
     * The CloudFormation resource type name for this resource class.
     */
    public final static java.lang.String RESOURCE_TYPE_NAME;

    public java.lang.String getPortfolioId() {
        return this.jsiiGet("portfolioId", java.lang.String.class);
    }

    /**
     * @cloudformation_attribute PortfolioName
     */
    public java.lang.String getPortfolioName() {
        return this.jsiiGet("portfolioName", java.lang.String.class);
    }

    public software.amazon.awscdk.services.servicecatalog.cloudformation.PortfolioResourceProps getPropertyOverrides() {
        return this.jsiiGet("propertyOverrides", software.amazon.awscdk.services.servicecatalog.cloudformation.PortfolioResourceProps.class);
    }
}
